@@ -24,6 +24,11 @@
 #undef tznm
 #undef mjed
 
+/* Various phrases that need to be repeated frequently in docstrings. */
+
+#define D " as a float giving radians, or a string giving degrees:minutes:seconds"
+#define H " as a float giving radians, or a string giving hours:minutes:seconds"
+
 /* Since different Body attributes are calculated with different
    routines, the compute() function itself just writes the time into
    the Body's `now' cache, and the VALID bits - stored in the user
@@ -290,7 +295,8 @@ static PyTypeObject AngleType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-     0,				/* tp_doc */
+     "An angle in radians that can print itself in an astronomical format.\n"
+     "Use ephem.degrees() and ephem.radians() to create one.", /* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -410,6 +416,8 @@ static int parse_mjd_from_datetime(PyObject *value, double *mjdp)
           *mjdp += PyDateTime_DATE_GET_HOUR(value) / 24.;
           *mjdp += PyDateTime_DATE_GET_MINUTE(value) / (24. * 60.);
           *mjdp += PyDateTime_DATE_GET_SECOND(value) / (24. * 60. * 60.);
+          *mjdp += PyDateTime_DATE_GET_MICROSECOND(value)
+               / (24. * 60. * 60. * 1000000.);
      }
      return 0;
 }
@@ -548,7 +556,11 @@ static PyTypeObject DateType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-     0,				/* tp_doc */
+     "Floating point value used by ephem to represent a date.\n"
+     "The value is the number of days since 1899 December 31 12:00 UT. When\n"
+     "creating an instance you can pass in a Python datetime instance,"
+     " timetuple,\nyear-month-day triple, or a plain float. Run str() on"
+     "this object to see\nthe UTC date it represents.", /* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -598,7 +610,11 @@ static int parse_angle(PyObject *value, double factor, double *result)
 	  double scaled;
 	  char *s = PyString_AsString(value);
           if (!s) return -1;
-          f_scansexa(s, &scaled);
+          if (f_scansexa(s, &scaled) == -1) {
+               PyErr_Format(PyExc_ValueError, "your angle string %r does not "
+                            "have the format [number[:number[:number]]]", s);
+               return -1;
+	  }
 	  *result = scaled / factor;
 	  return 0;
      } else {
@@ -628,8 +644,11 @@ static double to_angle(PyObject *value, double efactor, int *status)
                *status = -1;
                return 0;
           }
-          f_scansexa(s, &scaled);
-	  *status = 0;
+          *status = f_scansexa(s, &scaled);
+          if (*status == -1) {
+              PyErr_Format(PyExc_ValueError, "your angle string %r does not "
+                           "have the format [number[:number[:number]]]", s);
+          }
 	  return scaled / efactor;
      } else {
 	  PyErr_SetString(PyExc_TypeError,
@@ -641,15 +660,15 @@ static double to_angle(PyObject *value, double efactor, int *status)
 
 /* Hours stored as radian double. */
 
-static PyObject* getf_rh(PyObject *self, void *v)
+static PyObject* getd_rh(PyObject *self, void *v)
 {
-     return new_Angle(THE_FLOAT, radhr(1));
+     return new_Angle(THE_DOUBLE, radhr(1));
 }
 
-static int setf_rh(PyObject *self, PyObject *value, void *v)
+static int setd_rh(PyObject *self, PyObject *value, void *v)
 {
      int status;
-     THE_FLOAT = (float) to_angle(value, radhr(1), &status);
+     THE_DOUBLE = to_angle(value, radhr(1), &status);
      return status;
 }
 
@@ -902,7 +921,7 @@ static PyObject *Observer_radec_of(PyObject *self, PyObject *args,
      if (!rao) return 0;
      deco = new_Angle(dec, raddeg(1));
      if (!deco) return 0;
-     return Py_BuildValue("OO", rao, deco);
+     return Py_BuildValue("NN", rao, deco);
 }
 
 /*
@@ -953,26 +972,27 @@ static PyMethodDef Observer_methods[] = {
 
 static PyGetSetDef Observer_getset[] = {
      {"date", getd_mjd, setd_mjd, "Date", VOFF(n_mjd)},
-     {"lat", getd_rd, setd_rd, "Latitude (degrees north)", VOFF(n_lat)},
-     {"lon", getd_rd, setd_rd, "Longitude (degrees east)", VOFF(n_lng)},
+     {"lat", getd_rd, setd_rd, "Latitude north of the Equator" D, VOFF(n_lat)},
+     {"lon", getd_rd, setd_rd, "Longitude east of Greenwich" D, VOFF(n_lng)},
      {"elevation", get_elev, set_elev,
-      "Elevation above sea level (meters)", NULL},
+      "Elevation above sea level in meters", NULL},
      {"horizon", getd_rd, setd_rd,
       "The angle above (+) or below (-) the horizon at which an object"
-      " should be considered at the moment of rising or setting (degrees)",
+      " should be considered at the moment of rising or setting" D,
       VOFF(n_dip)},
      {"epoch", getd_mjd, setd_mjd, "Precession epoch", VOFF(n_epoch)},
 
      /* For compatibility with older scripts: */
-     {"long", getd_rd, setd_rd, "Longitude (degrees east)", VOFF(n_lng)},
+     {"long", getd_rd, setd_rd, "Longitude east of Greenwich" D, VOFF(n_lng)},
 
      {NULL}
 };
 
 static PyMemberDef Observer_members[] = {
-     {"temp", T_DOUBLE, OFF(n_temp), 0, "atmospheric temperature (C)"},
+     {"temp", T_DOUBLE, OFF(n_temp), 0,
+      "atmospheric temperature in degrees Celsius"},
      {"pressure", T_DOUBLE, OFF(n_pressure), 0,
-      "atmospheric pressure (mBar)"},
+      "atmospheric pressure in millibar"},
      {NULL}
 };
 
@@ -1000,7 +1020,11 @@ static PyTypeObject ObserverType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE,	/* tp_flags */
-     0,				/* tp_doc */
+     "Describes an observer standing on the Earth's surface.\n"
+     "This object can also store the time at which the observer is watching;\n"
+     "the epoch in which they want astrometric coordinates returned; and the\n"
+     "temperature and barometric pressure, which affect horizon refraction.\n"
+     "See Body.compute() for how to use instances of this class.", /* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -1267,8 +1291,8 @@ static PyObject* Body_repr(PyObject *body_object)
 
 static PyMethodDef Body_methods[] = {
      {"compute", (PyCFunction) Body_compute, METH_VARARGS | METH_KEYWORDS,
-      "compute the location of the body for the given date or Observer "
-      "(or for the current time if no date is supplied)"},
+      "compute the location of the body for the given date or Observer,"
+      " or for the current time if no date is supplied"},
      {"writedb", (PyCFunction) Body_writedb, METH_NOARGS,
       "return a string representation of the body "
       "appropriate for inclusion in an ephem database file"},
@@ -1652,39 +1676,30 @@ static int Set_gk(PyObject *self, PyObject *value, void *v)
 static PyGetSetDef Body_getset[] = {
      {"name", Get_name, 0, "object name (read-only string)"},
 
-     {"ra", Get_ra, 0, "right ascension (radians that print as hours of arc)"},
-     {"dec", Get_dec, 0, "declination (radians that print as degrees)"},
-     {"g_ra", Get_gaera, 0,
-      "apparent geocentric right ascension"
-      " (radians that print as hours of arc)"},
-     {"g_dec", Get_gaedec, 0,
-      "apparent geocentric declination"
-      " (radians that print as degrees)"},
-     {"a_ra", Get_astrora, 0,
-      "astrometric geocentric right ascension"
-      " (radians that print as hours of arc)"},
-     {"a_dec", Get_astrodec, 0,
-      "astrometric geocentric declination"
-      " (radians that print as degrees)"},
-     {"a_epoch", Get_epoch, 0, "equinox of body's astrometric right"
-      " ascension and declination (Date)"},
-     {"elong", Get_elong, 0, "elongation (radians that print as degrees)"},
+     {"ra", Get_ra, 0, "right ascension" H},
+     {"dec", Get_dec, 0, "declination" D},
+     {"g_ra", Get_gaera, 0, "apparent geocentric right ascension" H},
+     {"g_dec", Get_gaedec, 0, "apparent geocentric declination" D},
+     {"a_ra", Get_astrora, 0, "astrometric geocentric right ascension" H},
+     {"a_dec", Get_astrodec, 0, "astrometric geocentric declination" D},
+     {"a_epoch", Get_epoch, 0,
+      "date giving the equinox of the body's astrometric right"
+      " ascension and declination",
+     },
+     {"elong", Get_elong, 0, "elongation" D},
      {"mag", Get_mag, 0, "magnitude"},
-     {"size", Get_size, 0, "visual size (seconds of arc)"},
-     {"radius", Get_radius, 0, "visual radius (radians that print as degrees)"},
+     {"size", Get_size, 0, "visual size in arcseconds"},
+     {"radius", Get_radius, 0, "visual radius" D},
 
-     {"az", Get_az, 0, "azimuth (radians that print as degrees)"},
-     {"alt", Get_alt, 0, "altitude (radians that print as degrees)"},
+     {"az", Get_az, 0, "azimuth" D},
+     {"alt", Get_alt, 0, "altitude" D},
 
      {"rise_time", Get_rise_time, 0, "rise time"},
-     {"rise_az", Get_rise_az, 0, "rise azimuth"
-      " (radians that print as degrees)"},
+     {"rise_az", Get_rise_az, 0, "azimuth at which the body rises" D},
      {"transit_time", Get_transit_time, 0, "transit time"},
-     {"transit_alt", Get_transit_alt, 0, "transit altitude"
-      " (radians that print as degrees)"},
+     {"transit_alt", Get_transit_alt, 0, "transit altitude" D},
      {"set_time", Get_set_time, 0, "set time"},
-     {"set_az", Get_set_az, 0, "set azimuth"
-      " (radians that print as degrees)"},
+     {"set_az", Get_set_az, 0, "azimuth at which the body sets" D},
      {"circumpolar", Get_circumpolar, 0,
       "whether object remains above the horizon this day"},
      {"neverup", Get_neverup, 0,
@@ -1693,17 +1708,16 @@ static PyGetSetDef Body_getset[] = {
 };
 
 static PyGetSetDef Planet_getset[] = {
-     {"hlon", Get_hlong, 0, "heliocentric longitude"
-      " (radians that print as degrees)"},
-     {"hlat", Get_hlat, 0, "heliocentric latitude"
-      " (radians that print as degrees)"},
-     {"sun_distance", Get_sun_distance, 0, "distance from sun (AU)"},
-     {"earth_distance", Get_earth_distance, 0, "distance from earth (AU)"},
-     {"phase", Get_phase, 0, "phase (percent illuminated)"},
+     {"hlon", Get_hlong, 0,
+      "heliocentric longitude (but Sun().hlon means the hlon of Earth)" D},
+     {"hlat", Get_hlat, 0,
+      "heliocentric latitude (but Sun().hlat means the hlat of Earth)" D},
+     {"sun_distance", Get_sun_distance, 0, "distance from sun in AU"},
+     {"earth_distance", Get_earth_distance, 0, "distance from earth in AU"},
+     {"phase", Get_phase, 0, "phase as percent of the surface illuminated"},
 
      /* For compatibility with older scripts: */
-     {"hlong", Get_hlong, 0, "heliocentric longitude"
-      " (radians that print as degrees)"},
+     {"hlong", Get_hlong, 0, "heliocentric longitude" D},
 
      {NULL}
 };
@@ -1717,33 +1731,25 @@ static PyGetSetDef Planet_getset[] = {
 static PyGetSetDef PlanetMoon_getset[] = {
      {"name", Get_name, 0, "object name (read-only string)"},
 
-     {"a_ra", Get_astrora, 0,
-      "astrometric geocentric right ascension"
-      " (radians that print as hours of arc)"},
-     {"a_dec", Get_astrodec, 0,
-      "astrometric geocentric declination"
-      " (radians that print as degrees)"},
+     {"a_ra", Get_astrora, 0, "astrometric geocentric right ascension" H},
+     {"a_dec", Get_astrodec, 0, "astrometric geocentric declination" D},
 
-     {"g_ra", Get_gaera, 0,
-      "apparent geocentric right ascension"
-      " (radians that print as hours of arc)"},
-     {"g_dec", Get_gaedec, 0,
-      "apparent geocentric declination"
-      " (radians that print as degrees)"},
+     {"g_ra", Get_gaera, 0, "apparent geocentric right ascension" H},
+     {"g_dec", Get_gaedec, 0, "apparent geocentric declination" D},
 
-     {"ra", Get_ra, 0, "right ascension (radians that print as hours of arc)"},
-     {"dec", Get_dec, 0, "declination (radians that print as degrees)"},
+     {"ra", Get_ra, 0, "right ascension" H},
+     {"dec", Get_dec, 0, "declination" D},
 
-     {"az", Get_az, 0, "azimuth (radians that print as degrees)"},
-     {"alt", Get_alt, 0, "altitude (radians that print as degrees)"},
+     {"az", Get_az, 0, "azimuth" D},
+     {"alt", Get_alt, 0, "altitude" D},
 
      {"x", Get_x, 0, "how far east or west of its planet"
-      " the moon lies in the sky (in planet radii, east is positive)"},
+      " the moon lies in the sky in planet radii; east is positive"},
      {"y", Get_y, 0, "how far north or south of its planet"
-      " the moon lies in the sky (in planet radii, south is positive)"},
+      " the moon lies in the sky in planet radii; south is positive"},
      {"z", Get_z, 0, "how much closer or farther from Earth the moon is"
       " than its planet"
-      " (in planet radii, closer to Earth is positive)"},
+      " in planet radii; closer to Earth is positive"},
 
      {"earth_visible", Get_earth_visible, 0, "whether visible from earth"},
      {"sun_visible", Get_sun_visible, 0, "whether visible from sun"},
@@ -1751,36 +1757,28 @@ static PyGetSetDef PlanetMoon_getset[] = {
 };
 
 static PyGetSetDef Moon_getset[] = {
-     {"libration_lat", Get_libration_lat, 0,
-      "lunar libration in latitude (radians that print as degrees)"},
+     {"libration_lat", Get_libration_lat, 0, "lunar libration in latitude" D},
      {"libration_long", Get_libration_long, 0,
-      "lunar libration in longitude (radians that print as degrees)"},
-     {"colong", Get_colong, 0,
-      "lunar selenographic colongitude (radians that print as degrees)"},
+      "lunar libration in longitude" D},
+     {"colong", Get_colong, 0, "lunar selenographic colongitude" D},
      {"moon_phase", Get_moon_phase, 0,
       "fraction of lunar surface illuminated when viewed from earth"},
      {"subsolar_lat", Get_subsolar_lat, 0,
-      "lunar latitude of subsolar point (radians that print as degrees)"},
+      "lunar latitude of subsolar point" D},
      {NULL}
 };
 
 static PyGetSetDef Jupiter_getset[] = {
-     {"cmlI", Get_cmlI, 0,
-      "central meridian longitude, System I (radians that print as degrees)"
-     },
-     {"cmlII", Get_cmlII, 0,
-      "central meridian longitude, System II (radians that print as degrees)"
-     },
+     {"cmlI", Get_cmlI, 0, "central meridian longitude, System I" D},
+     {"cmlII", Get_cmlII, 0, "central meridian longitude, System II" D},
      {NULL}
 };
 
 static PyGetSetDef Saturn_getset[] = {
      {"earth_tilt", Get_earth_tilt, 0,
-      "tilt of rings towards Earth (radians that print as degrees,"
-      " positive for southward tilt and negative for northward)"},
+      "tilt of rings towards Earth, positive for southward tilt," D},
      {"sun_tilt", Get_sun_tilt, 0,
-      "tilt of rings towards Sun radians that print as degrees,"
-      " positive for southward tilt and negative for northward)"},
+      "tilt of rings towards Sun, positive for southward tilt," D},
      {NULL}
 };
 
@@ -1791,9 +1789,9 @@ static PyGetSetDef FixedBody_getset[] = {
      {"_ratio", get_f_ratio, set_f_ratio,
       "ratio of minor to major diameter", VOFF(f_ratio)},
      {"_pa", get_f_pa, set_f_pa, "position angle E of N", VOFF(f_pa)},
-     {"_epoch", getf_mjd, setf_mjd, "epoch for _ra and _dec", VOFF(f_epoch)},
-     {"_ra", getf_rh, setf_rh, "fixed right ascension", VOFF(f_RA)},
-     {"_dec", getf_rd, setf_rd, "fixed declination", VOFF(f_dec)},
+     {"_epoch", getd_mjd, setd_mjd, "epoch for _ra and _dec", VOFF(f_epoch)},
+     {"_ra", getd_rh, setd_rh, "fixed right ascension", VOFF(f_RA)},
+     {"_dec", getd_rd, setd_rd, "fixed declination", VOFF(f_dec)},
      {"_pmra", getf_proper_ra, setf_proper_ra,
       "right ascension proper motion", 0},
      {"_pmdec", getf_proper_dec, setf_proper_dec,
@@ -1885,12 +1883,12 @@ static PyGetSetDef EarthSatellite_getset[] = {
 
      /* results: */
 
-     {"sublat", Get_sublat, 0, "latitude below satellite (degrees north)"},
-     {"sublong", Get_sublong, 0, "longitude below satellite (degrees east)"},
-     {"elevation", Get_elevation, 0, "height above sea level (meters)"},
-     {"range", Get_range, 0, "distance from observer to satellite (meters)"},
+     {"sublat", Get_sublat, 0, "latitude beneath satellite" D},
+     {"sublong", Get_sublong, 0, "longitude beneath satellite" D},
+     {"elevation", Get_elevation, 0, "height above sea level in meters"},
+     {"range", Get_range, 0, "distance from observer to satellite in meters"},
      {"range_velocity", Get_range_velocity, 0,
-      "range rate of change (meters per second)"},
+      "range rate of change in meters per second"},
      {"eclipsed", Get_eclipsed, 0, "whether satellite is in earth's shadow"},
      {NULL}
 };
@@ -1921,6 +1919,8 @@ static PyMemberDef EarthSatellite_members[] = {
  * rather unusual but reflects the fact that all of these are just
  * various wrappers around the same X Obj structure.
  */
+static char body_doc[] =
+     "A celestial body, that can compute() its sky position";
 
 static PyTypeObject BodyType = {
      PyObject_HEAD_INIT(NULL)
@@ -1944,7 +1944,7 @@ static PyTypeObject BodyType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-     0,				/* tp_doc */
+     body_doc,			/* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -1987,7 +1987,7 @@ static PyTypeObject PlanetType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-     0,				/* tp_doc */
+     body_doc,			/* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -2030,7 +2030,7 @@ static PyTypeObject PlanetMoonType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-     0,				/* tp_doc */
+     body_doc,			/* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -2073,7 +2073,7 @@ static PyTypeObject JupiterType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-     0,				/* tp_doc */
+     "Create a Body instance representing Jupiter.",			/* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -2116,7 +2116,7 @@ static PyTypeObject SaturnType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-     0,				/* tp_doc */
+     "Create a Body instance representing Saturn.",			/* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -2159,7 +2159,7 @@ static PyTypeObject MoonType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-     0,				/* tp_doc */
+     "Create a Body Instance representing the Moon.",			/* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -2202,7 +2202,7 @@ static PyTypeObject FixedBodyType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-     0,				/* tp_doc */
+     body_doc,			/* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -2245,7 +2245,7 @@ static PyTypeObject BinaryStarType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-     0,				/* tp_doc */
+     body_doc,			/* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -2288,7 +2288,7 @@ static PyTypeObject EllipticalBodyType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-     0,				/* tp_doc */
+     body_doc,			/* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -2331,7 +2331,7 @@ static PyTypeObject HyperbolicBodyType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-     0,				/* tp_doc */
+     body_doc,			/* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -2374,7 +2374,7 @@ static PyTypeObject ParabolicBodyType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-     0,				/* tp_doc */
+     body_doc,			/* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -2417,7 +2417,7 @@ static PyTypeObject EarthSatelliteType = {
      0,				/* tp_setattro */
      0,				/* tp_as_buffer */
      Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE,	/* tp_flags */
-     0,				/* tp_doc */
+     body_doc,			/* tp_doc */
      0,				/* tp_traverse */
      0,				/* tp_clear */
      0,				/* tp_richcompare */
@@ -2496,12 +2496,16 @@ static int separation_arg(PyObject *arg, double *lngi, double *lati)
 static PyObject* separation(PyObject *self, PyObject *args)
 {
      double plat, plng, qlat, qlng;
-     double spy, cpy, px, qx, sqy, cqy;
+     double spy, cpy, px, qx, sqy, cqy, cosine;
      PyObject *p, *q;
      if (!PyArg_ParseTuple(args, "OO:separation", &p, &q)) return 0;
      if (separation_arg(p, &plng, &plat)) return 0;
      if (separation_arg(q, &qlng, &qlat)) return 0;
 
+     /* rounding errors in the trigonometry might return >0 for this case */
+     if ((plat == qlat) && (plng == qlng))
+          return new_Angle(0.0, raddeg(1));
+
      spy = sin (plat);
      cpy = cos (plat);
      px = plng;
@@ -2509,7 +2513,11 @@ static PyObject* separation(PyObject *self, PyObject *args)
      sqy = sin (qlat);
      cqy = cos (qlat);
 
-     return new_Angle(acos(spy*sqy + cpy*cqy*cos(px-qx)), raddeg(1));
+     cosine = spy*sqy + cpy*cqy*cos(px-qx);
+     if (cosine >= 1.0)  /* rounding sometimes makes this >1 */
+          return new_Angle(0.0, raddeg(1));
+
+     return new_Angle(acos(cosine), raddeg(1));
 }
 
 /* Read various database formats, with strings as input. */
@@ -2804,40 +2812,40 @@ static PyObject *my_eq_ecl(PyObject *self, PyObject *args)
      double mjd, ra, dec, lg, lt;
      if (!PyArg_ParseTuple(args, "ddd:eq_ecl", &mjd, &ra, &dec)) return 0;
      eq_ecl(mjd, ra, dec, &lt, &lg);
-     return Py_BuildValue("(OO)", build_degrees(lg), build_degrees(lt));
+     return Py_BuildValue("NN", build_degrees(lg), build_degrees(lt));
 }
 
 static PyObject *my_ecl_eq(PyObject *self, PyObject *args)
 {
      double mjd, ra, dec, lg, lt;
-     if (!PyArg_ParseTuple(args, "ddd:eq_ecl", &mjd, &lg, &lt)) return 0;
+     if (!PyArg_ParseTuple(args, "ddd:ecl_eq", &mjd, &lg, &lt)) return 0;
      ecl_eq(mjd, lt, lg, &ra, &dec);
-     return Py_BuildValue("(OO)", build_hours(ra), build_degrees(dec));
+     return Py_BuildValue("NN", build_hours(ra), build_degrees(dec));
 }
 
 static PyObject *my_eq_gal(PyObject *self, PyObject *args)
 {
      double mjd, ra, dec, lg, lt;
-     if (!PyArg_ParseTuple(args, "ddd:eq_ecl", &mjd, &ra, &dec)) return 0;
+     if (!PyArg_ParseTuple(args, "ddd:eq_gal", &mjd, &ra, &dec)) return 0;
      eq_gal(mjd, ra, dec, &lt, &lg);
-     return Py_BuildValue("(OO)", build_degrees(lg), build_degrees(lt));
+     return Py_BuildValue("NN", build_degrees(lg), build_degrees(lt));
 }
 
 static PyObject *my_gal_eq(PyObject *self, PyObject *args)
 {
      double mjd, ra, dec, lg, lt;
-     if (!PyArg_ParseTuple(args, "ddd:eq_ecl", &mjd, &lg, &lt)) return 0;
+     if (!PyArg_ParseTuple(args, "ddd:gal_eq", &mjd, &lg, &lt)) return 0;
      gal_eq(mjd, lt, lg, &ra, &dec);
-     return Py_BuildValue("(OO)", build_hours(ra), build_degrees(dec));
+     return Py_BuildValue("NN", build_hours(ra), build_degrees(dec));
 }
 
 static PyObject *my_precess(PyObject *self, PyObject *args)
 {
      double mjd1, mjd2, ra, dec;
-     if (!PyArg_ParseTuple(args, "dddd:eq_ecl", &mjd1, &mjd2, &ra, &dec))
+     if (!PyArg_ParseTuple(args, "dddd:precess", &mjd1, &mjd2, &ra, &dec))
           return 0;
      precess(mjd1, mjd2, &ra, &dec);
-     return Py_BuildValue("(OO)", build_hours(ra), build_degrees(dec));
+     return Py_BuildValue("NN", build_hours(ra), build_degrees(dec));
 }
 
 static PyObject *_next_pass(PyObject *self, PyObject *args)
@@ -2915,8 +2923,7 @@ static PyMethodDef libastro_methods[] = {
      {"readdb", readdb, METH_VARARGS, "Read an ephem database entry"},
      {"readtle", readtle, METH_VARARGS, "Read TLE-format satellite elements"},
      {"separation", separation, METH_VARARGS,
-      "Return the angular separation between two objects or positions "
-      "(degrees)"},
+      "Return the angular separation between two objects or positions" D},
 
      {"uranometria", uranometria, METH_VARARGS,
       "given right ascension and declination (in radians), return the page"
